//
//  DatalinkParametersSection.swift
//  Example
//
//  Created by Yunus TÜR on 23.06.2022.
//  Copyright © 2022 Ecospend. All rights reserved.
//

import SwiftUI
import PayByBank

struct DatalinkParametersSection: View {
    
    @State private var isAffordabilityValid: Bool = false
    @State private var affordability: AffordabilityParameters? = nil
    
    @State private var isVerificationValid: Bool = false
    @State private var verification: VerificationParameters? = nil
    
    @State private var isFinancialValid: Bool = false
    @State private var financial: FinancialMultiParameters? = nil
    
    @State private var isCategoryValid: Bool = false
    @State private var category: CategoryAggregationParameters? = nil
    
    @State private var enabled: Bool = false
    @Binding private(set) var valid: Bool
    @Binding private(set) var value: FinancialReportParameters?
    
    var body: some View {
        List {
            Section(header: header) {
                Group {
                    DatalinkAffordabilitySection(valid: $isAffordabilityValid, value: $affordability)
                    DatalinkVerificationSection(valid: $isVerificationValid, value: $verification)
                    DatalinkFinancialSection(valid: $isFinancialValid, value: $financial)
                    DatalinkCategoryAggregationSection(valid: $isCategoryValid, value: $category)
                }
                .disabled(!enabled)
                .opacity(!enabled ? 0.5 : 1)
            }
        }
        .onChange(of: enabled) { _ in validate() }
        .onChange(of: isAffordabilityValid) { _ in validate() }
        .onChange(of: isVerificationValid) { _ in validate() }
        .onChange(of: isFinancialValid) { _ in validate() }
        .onChange(of: isCategoryValid) { _ in validate() }
        .onAppear { validate() }
    }
    
    @ViewBuilder
    var header: some View {
        Toggle(L10n.sectionParameters.localized, isOn: $enabled)
    }
    
    func validate() {
        valid = isAffordabilityValid && isVerificationValid && isVerificationValid && isCategoryValid
        
        value = {
            guard enabled else { return nil }
            let affordabilityList: [AffordabilityParameters]? = {
                guard let affordability = affordability else { return nil }
                return [affordability]
            }()
            return FinancialReportParameters(affordability: affordabilityList,
                                             verification: verification,
                                             financial: financial,
                                             categoryAggregation: category)
        }()
    }
}

struct DatalinkParametersSection_Previews: PreviewProvider {
    static var previews: some View {
        DatalinkParametersSection(valid: .constant(true), value: .constant(nil))
    }
}
